@@ -8,8 +8,9 @@ use Carp;
 use Data::Dump qw( dump );
 use Scalar::Util qw( blessed );
 use SWISH::Prog::Config;
+use SWISH::Prog::InvIndex;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 __PACKAGE__->mk_accessors(qw( aggregator ));
 
@@ -72,15 +73,20 @@ my %ashort = (
     object => 'SWISH::Prog::Aggregator::Object',
 );
 my %ishort = (
-    native => 'SWISH::Prog::Indexer::Native',
-    xapian => 'SWISH::Prog::Indexer::Xapian',
-    ks     => 'SWISH::Prog::Indexer::KinoSearch',
-    dbi    => 'SWISH::Prog::Indexer::DBI',
+    native => 'SWISH::Prog::Native::Indexer',
+    xapian => 'SWISH::Prog::Xapian::Indexer',
+    ks     => 'SWISH::Prog::KinoSearch::Indexer',
+    dbi    => 'SWISH::Prog::DBI::Indexer',
 );
 
 sub init {
     my $self = shift;
 
+    # search mode requires only invindex
+    if ( $self->{query} && !$self->{indexer} && !$self->{aggregator} ) {
+        return;
+    }
+
     # need to make sure we have 3 items:
     # aggregator
     # indexer
@@ -103,7 +109,7 @@ sub init {
         }
         $indexer = $indexer->new(
             debug    => $self->debug,
-            invindex => $self->{invindex},
+            invindex => $self->{invindex},    # may be undef
             verbose  => $self->verbose
         );
     }
@@ -161,13 +167,21 @@ sub init {
     $self->{aggregator} = $aggregator;
 }
 
-=head2 run
+=head2 run( I<collection> )
 
-Execute the program.
+Execute the program. This is an alias for index().
 
 =cut
 
-sub run {
+*run = \&index;
+
+=head2 index( I<collection> )
+
+Add items in I<collection> to the invindex().
+
+=cut
+
+sub index {
     my $self = shift;
     my $aggregator = $self->aggregator or croak 'aggregator required';
     unless ( $aggregator->isa('SWISH::Prog::Aggregator') ) {
@@ -187,7 +201,11 @@ Returns the aggregator's config() object.
 =cut
 
 sub config {
-    shift->aggregator->config;
+    my $self = shift;
+    if ( $self->aggregator ) {
+        return $self->aggregator->config;
+    }
+    return $self->{config} || SWISH::Prog::Config->new;
 }
 
 =head2 invindex
@@ -197,7 +215,13 @@ Returns the indexer's invindex.
 =cut
 
 sub invindex {
-    shift->indexer->invindex;
+    my $self = shift;
+    if ( $self->aggregator ) {
+        return $self->indexer->invindex;
+    }
+    return blessed( $self->{invindex} )
+        ? $self->{invindex}
+        : SWISH::Prog::InvIndex->new( path => $self->{invindex} );
 }
 
 =head2 indexer
