@@ -1,59 +1,4 @@
 package SWISH::Prog::Config;
-
-=head1 NAME
-
-SWISH::Prog::Config - read & write Swish-e config files
-
-=head1 SYNOPSIS
-
- use SWISH::Prog::Config;
- 
- my $config = SWISH::Prog::Config->new;
- 
- 
-=head1 DESCRIPTION
-
-The SWISH::Prog::Config class is intended to be accessed via SWISH::Prog new().
-
-See the Swish-e documentation for a list of configuration parameters.
-Each parameter has an accessor/mutator method as part of the Config object.
-Some preliminary compatability is offered for Swish::Config
-with XML format config files.
-
-B<NOTE:> Every config parameter can take either a scalar or an array ref as a value.
-In addition, you may append config values to any existing values by passing an additional
-true argument. The return value of any 'get' is always an array ref.
-
-Example:
-
- $config->MetaNameAlias( ['foo bar', 'one two', 'red yellow'] );
- $config->MetaNameAlias( 'green blue', 1 );
- print join("\n", @{ $config->MetaNameAlias }), " \n";
- # would print:
- # foo bar
- # one two
- # red yellow
- # green blue
- 
-
-
-=head1 METHODS
-
-NOTE this class inherits from Class::Accessor and not SWISH::Prog::Class.
-
-=head2 new( I<params> )
-
-Instatiate a new Config object. Takes a hash of key/value pairs, where each key
-may be a Swish-e configuration parameter.
-
-Example:
-
- my $config = SWISH::Prog::Config->new( DefaultContents => 'HTML*' );
- 
- print "DefaultContents is ", $config->DefaultContents, "\n";
- 
-=cut
-
 use strict;
 use warnings;
 use Carp;
@@ -68,7 +13,7 @@ use overload(
     fallback => 1,
 );
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 our $XMLer = Search::Tools::XML->new;
 
@@ -168,6 +113,59 @@ my @Opts = qw(
 
 __PACKAGE__->mk_accessors( qw( file debug verbose ), @Opts );
 
+=head1 NAME
+
+SWISH::Prog::Config - read/write Swish-e config files
+
+=head1 SYNOPSIS
+
+ use SWISH::Prog::Config;
+ 
+ my $config = SWISH::Prog::Config->new;
+ 
+ 
+=head1 DESCRIPTION
+
+The SWISH::Prog::Config class is intended to be accessed via SWISH::Prog new().
+
+See the Swish-e documentation for a list of configuration parameters.
+Each parameter has an accessor/mutator method as part of the Config object.
+Some preliminary compatability is offered for Swish::Config
+with XML format config files.
+
+B<NOTE:> Every config parameter can take either a scalar or an array ref as a value.
+In addition, you may append config values to any existing values by passing an additional
+true argument. The return value of any 'get' is always an array ref.
+
+Example:
+
+ $config->MetaNameAlias( ['foo bar', 'one two', 'red yellow'] );
+ $config->MetaNameAlias( 'green blue', 1 );
+ print join("\n", @{ $config->MetaNameAlias }), " \n";
+ # would print:
+ # foo bar
+ # one two
+ # red yellow
+ # green blue
+ 
+
+=head1 METHODS
+
+NOTE this class inherits from Class::Accessor and not SWISH::Prog::Class.
+
+=head2 new( I<params> )
+
+Instatiate a new Config object. Takes a hash of key/value pairs, where each key
+may be a Swish-e configuration parameter.
+
+Example:
+
+ my $config = SWISH::Prog::Config->new( DefaultContents => 'HTML*' );
+ 
+ print "DefaultContents is ", $config->DefaultContents, "\n";
+ 
+=cut
+
 sub new {
     my $class = shift;
     my $opts  = ref( $_[0] ) ? $_[0] : {@_};
@@ -279,9 +277,8 @@ sub read2 {
     # filter include syntax to work with Config::General's
     $buf =~ s,IncludeConfigFile (.+?)\n,<<include $1>>\n,g;
 
-    my $dir = Path::Class::File->new($file)->parent;
+    my $dir = Path::Class::file($file)->parent;
 
-    # TODO are these the right opts?
     my $c = Config::General->new(
         -String          => $buf,
         -IncludeRelative => 1,
@@ -336,6 +333,23 @@ sub write2 {
     return $self->file;
 }
 
+=head2 write3( I<path/file> )
+
+Write config object to file in SWISH::3::Config XML format.
+
+=cut
+
+sub write3 {
+    my $self = shift;
+    my $file = shift or croak "file required";
+
+    write_file( "$file", $self->ver2_to_ver3 );
+
+    warn "wrote config file $file" if $self->debug;
+
+    return $self;
+}
+
 =head2 as_hash
 
 Returns current Config object as a hash ref.
@@ -401,22 +415,22 @@ sub _write_utf8 {
     print {$file} $buf;
 }
 
-=head2 ver2_to_xml( I<file> )
+=head2 ver2_to_ver3( I<file> )
 
 Utility method for converting Swish-e version 2 style config files
-to SWISH::Config XML style.
+to SWISH::3::Config XML style.
 
 Converts I<file> to XML format and returns as XML string.
 
 B<NOTE:> This API is liable to change as SWISH::Config is developed.
 
-  my $xmlconf = $config->ver2_to_xml( 'my/file.config' );
+  my $xmlconf = $config->ver2_to_ver3( 'my/file.config' );
 
 If I<file> is omitted, uses the current values in the calling object.
 
 =cut
 
-sub ver2_to_xml {
+sub ver2_to_ver3 {
     my $self = shift;
     my $file = shift;
 
@@ -445,26 +459,32 @@ sub ver2_to_xml {
     # TODO  what if this encoding is not correct?
     my $xml = <<EOF;
 <?xml version="1.0" encoding="UTF-8"?>
-<!-- converted with SWISH::Prog::Config ver2_to_xml() $time -->
-<swishconfig>
+<!-- converted with SWISH::Prog::Config ver2_to_ver3() $time -->
+<swish>
+ <Index>
+  <Format>Native</Format>
+ </Index>
+ <!-- this feature is not yet fully supported -->
 EOF
 
-KEY: for my $k ( sort keys %$config ) {
-        my @args = ref $config->{$k} ? @{ $config->{$k} } : ( $config->{$k} );
+    #warn dump $config;
 
-    ARG: for my $arg (@args) {
-            $xml .= "  <$k";
-            if ( $takes_arg{$k} ) {
-                my ( $class, $v ) = ( $arg =~ m/^\ *(\S+)\ +(.+)$/ );
-                $arg = $v;
-                $xml .= ' type="' . $XMLer->utf8_safe($class) . '"';
-            }
-            $xml .= '>' . $XMLer->utf8_safe($arg) . "</$k>\n";
+#KEY: for my $k ( sort keys %$config ) {
+#        my @args = ref $config->{$k} ? @{ $config->{$k} } : ( $config->{$k} );
+#
+#    ARG: for my $arg (@args) {
+#            $xml .= "  <$k";
+#            if ( $takes_arg{$k} ) {
+#                my ( $class, $v ) = ( $arg =~ m/^\ *(\S+)\ +(.+)$/ );
+#                $arg = $v;
+#                $xml .= ' type="' . $XMLer->utf8_safe($class) . '"';
+#            }
+#            $xml .= '>' . $XMLer->utf8_safe($arg) . "</$k>\n";
+#
+#        }
+#    }
 
-        }
-    }
-
-    $xml .= "</swishconfig>\n";
+    $xml .= "</swish>\n";
 
     return $xml;
 
@@ -476,9 +496,10 @@ __END__
 
 =head1 TODO
 
-IgnoreTotalWordCountWhenRanking defaults to 0 which is B<not> the default in Swish-e.
-This is to make the RankScheme feature work by default. Really, the default should be
-0 in Swish-e itself.
+IgnoreTotalWordCountWhenRanking defaults to 0 
+which is B<not> the default in Swish-e.
+This is to make the RankScheme feature work by default. 
+Really, the default should be 0 in Swish-e itself.
 
 =head1 SEE ALSO
 
