@@ -6,12 +6,13 @@ use base qw( SWISH::Prog::Class );
 use Carp;
 use Path::Class;
 use Scalar::Util qw( blessed );
+use SWISH::Prog::InvIndex::Meta;
 use overload(
     '""'     => sub { shift->path },
     fallback => 1,
 );
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 __PACKAGE__->mk_accessors(qw( path clobber ));
 
@@ -23,8 +24,30 @@ sub init {
         $self->path( dir($path) );
     }
 
-    $self->{clobber} = 1 unless exists $self->{clobber};
+    $self->{clobber} = 0 unless exists $self->{clobber};
+}
 
+sub new_from_meta {
+    my $self = shift;
+
+    # open swish.xml meta file
+    my $meta = $self->meta;
+
+    # parse for index format
+    my $format = $meta->Index->{Format};
+
+    # create new object and re-set $self
+    my $newclass = "SWISH::Prog::${format}::InvIndex";
+
+    warn "reblessing $self into $newclass";
+
+    eval "require $newclass";
+    croak $@ if $@;
+
+    return $newclass->new(
+        path    => $self->{path},
+        clobber => $self->{clobber},
+    );
 }
 
 sub open {
@@ -39,14 +62,24 @@ sub open {
     }
 
     if ( !-d $self->path ) {
-        $self->path->mkpath($self->verbose);
+        carp "no path $self->{path} -- mkpath";
+        $self->path->mkpath( $self->verbose );
     }
 
     1;
 }
 
+sub open_ro {
+    shift->open(@_);
+}
+
 sub close { 1; }
 
+sub meta {
+    my $self = shift;
+    return SWISH::Prog::InvIndex::Meta->new( invindex => $self );
+}
+
 =pod
 
 =head1 NAME
@@ -84,13 +117,20 @@ information about the index.
 
 =head2 open
 
-Open the index for reading/writing. Subclasses should implement this per
+Open the invindex for reading/writing. Subclasses should implement this per
 their IR library specifics.
 
 This base open() method will rmtree( path() ) if clobber() is true,
 and will mkpath() if path() does not exist. So SUPER::open() should
 do something sane at minimum.
 
+=head2 open_ro
+
+Open the invindex in read-only mode. This is typical when searching
+the invindex.
+
+The default open_ro() method will simply call through to open().
+
 =head2 close
 
 Close the index. Subclasses should implement this per
@@ -101,6 +141,11 @@ their IR library specifics.
 Get/set the boolean indicating whether the index should overwrite
 any existing index with the same name. The default is true.
 
+=head2 new_from_meta
+
+Returns a new instance like new() does, blessed into the appropriate
+class indicated by the C<swish.xml> meta header file.
+
 =cut
 
 1;
